###########################
Keithley DMM6500 Multimeter
###########################

.. autoclass:: pymeasure.instruments.keithley.KeithleyDMM6500
    :members:
    :show-inheritance:
    :exclude-members: ask, control, clear, measurement, read, setting, values, write

.. autoclass:: pymeasure.instruments.keithley.keithleyDMM6500.ScannerCard2000Channel
    :members:
    :show-inheritance:
